//+------------------------------------------------------------------+
//|                                    Quantum Trading Delta RSI.mq4 |
//|                            Copyright 2016, Quantum Trading Corp. |
//|                                   http://www.Quantum Trading.net |
//+------------------------------------------------------------------+
#property copyright "Copyright 2016, Quantum Trading Corp."
#property link      "http://www.Quantum Trading.net"
#property version   "1.00"
#property strict
#property indicator_buffers 6
#property indicator_plots   6
#property indicator_separate_window

input int RSIPeriod1 = 14; // Fast RSI Period
input int RSIPeriod2 = 50; // Slow RSI Period
input int Level=50; // Signal Level
input int bar=0; // Bar
input color activeUp=clrWhite; // OverBuy Color
input color activeDown=clrBlack; // OverSell Color
input color passive=clrGray; // No Signal Color
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
enum TypeGraph
  {
   Histogram=0,// Full Histogram
   Cute=1,// Cute Histogram
  };
//--- input parameters
extern ENUM_TIMEFRAMES TimeFrame=PERIOD_CURRENT;
input TypeGraph TypeGr=Histogram; // Type graph

double rsi1[];
double rsi2[];
double delta[];
double UP[];
double Down[];
double Pass[];
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- indicator buffers mapping
   SetIndexBuffer(0,rsi1);
   SetIndexBuffer(1,rsi2);
   SetIndexBuffer(2,delta);
   SetIndexBuffer(3,UP);
   SetIndexBuffer(4,Down);
   SetIndexBuffer(5,Pass);
   IndicatorShortName("Quantum Trading Delta RSI");
   SetIndexStyle(0,DRAW_NONE,STYLE_SOLID,1,clrYellow);
   SetIndexStyle(1,DRAW_NONE,STYLE_SOLID,1,clrOrange);
   TimeFrame=MathMax(TimeFrame,_Period);
   if(TypeGr==1)
     {
      SetIndexStyle(2,DRAW_NONE,STYLE_SOLID,1,clrGray);
      SetIndexStyle(3,DRAW_HISTOGRAM,STYLE_SOLID,4,activeUp);
      SetIndexStyle(4,DRAW_HISTOGRAM,STYLE_SOLID,4,activeDown);
      SetIndexStyle(5,DRAW_HISTOGRAM,STYLE_SOLID,4,passive);
      IndicatorSetDouble(INDICATOR_MINIMUM,0);
      IndicatorSetDouble(INDICATOR_MAXIMUM,1);
        }else{
      SetIndexStyle(2,DRAW_NONE,STYLE_SOLID,1,clrGray);
      SetIndexStyle(3,DRAW_HISTOGRAM,STYLE_SOLID,0,activeUp);
      SetIndexStyle(4,DRAW_HISTOGRAM,STYLE_SOLID,0,activeDown);
      SetIndexStyle(5,DRAW_HISTOGRAM,STYLE_SOLID,0,passive);
     }
//---
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {
//---
   int limit;
   static bool alrt=false;
   static datetime altime=0;
   int maxLevel = 100-(100-Level);
   int minLevel = 100-Level;

//---
   if(rates_total<=1)
      return(0);
//--- last counted bar will be recounted
   limit=rates_total-prev_calculated;
   if(prev_calculated>0)
      limit=limit+1;
      limit = MathMin(Bars-1,MathMax(limit,2*TimeFrame/_Period));
      

   for(int x=limit-1; x>=0; x--)
     {
      int y = iBarShift(NULL,TimeFrame,Time[x]);
      rsi1[x] = iRSI(Symbol(), TimeFrame, RSIPeriod1, PRICE_CLOSE, y+bar);
      rsi2[x] = iRSI(Symbol(), TimeFrame, RSIPeriod2, PRICE_CLOSE, y+bar);
      delta[x] = rsi1[x]-rsi2[x];
      UP[x]=EMPTY_VALUE;
      Down[x]=EMPTY_VALUE;
      if(TypeGr==1)
        {
         Pass[x]=1;
           }else{
         Pass[x]=delta[x];
        }
      if(rsi2[x]>maxLevel && rsi1[x]>rsi2[x])
        {
         if(TypeGr==1)
           {
            UP[x]=1;
              }else{
            UP[x]=delta[x];
           }
         Pass[x]=EMPTY_VALUE;
        }
      if(rsi2[x]<minLevel && rsi1[x]<rsi2[x])
        {
         if(TypeGr==1)
           {
            Down[x]=1;
              }else{
            Down[x]=delta[x];
           }
         Pass[x]=EMPTY_VALUE;
        }
     }
//--- return value of prev_calculated for next call
   return(rates_total);
  }
//+------------------------------------------------------------------+
